Struct rooster::instruction::DelegateTransferArgs
source · pub struct DelegateTransferArgs {
pub amount: u64,
pub auth_data: AuthorizationData,
}Fields
amount: u64auth_data: AuthorizationDataTrait Implementations
sourceimpl BorshDeserialize for DelegateTransferArgs
impl BorshDeserialize for DelegateTransferArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
sourceimpl Clone for DelegateTransferArgs
impl Clone for DelegateTransferArgs
sourcefn clone(&self) -> DelegateTransferArgs
fn clone(&self) -> DelegateTransferArgs
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for DelegateTransferArgs
impl Debug for DelegateTransferArgs
sourceimpl PartialEq for DelegateTransferArgs
impl PartialEq for DelegateTransferArgs
sourcefn eq(&self, other: &DelegateTransferArgs) -> bool
fn eq(&self, other: &DelegateTransferArgs) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl Eq for DelegateTransferArgs
impl StructuralEq for DelegateTransferArgs
impl StructuralPartialEq for DelegateTransferArgs