Struct rooster::instruction::WithdrawArgs
source · #[repr(C)]pub struct WithdrawArgs {
pub auth_data: AuthorizationData,
}Fields
auth_data: AuthorizationDataTrait Implementations
sourceimpl BorshDeserialize for WithdrawArgs
impl BorshDeserialize for WithdrawArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
sourceimpl BorshSerialize for WithdrawArgs
impl BorshSerialize for WithdrawArgs
sourceimpl Clone for WithdrawArgs
impl Clone for WithdrawArgs
sourcefn clone(&self) -> WithdrawArgs
fn clone(&self) -> WithdrawArgs
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for WithdrawArgs
impl Debug for WithdrawArgs
sourceimpl PartialEq for WithdrawArgs
impl PartialEq for WithdrawArgs
sourcefn eq(&self, other: &WithdrawArgs) -> bool
fn eq(&self, other: &WithdrawArgs) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl Eq for WithdrawArgs
impl StructuralEq for WithdrawArgs
impl StructuralPartialEq for WithdrawArgs